/**The MIT License (MIT)
 
 Copyright (c) 2018 by ThingPulse Ltd., https://thingpulse.com
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 */
// Check this after changing boards (nodeMCU, WeMos, etc.)
// https://docs.thingpulse.com/guides/wifi-color-display-kit/

// Modifications (from ThingPulse original code) by http://www.frogymandias.org
// MIT license is maintained
 
#ifndef SETTINGS_H
#define SETTINGS_H
#include <Arduino.h>
#include "TZinfo.h"

// (Frogymandias mod) This is where all the personal information is kept
// If you are making weather stations for friends that have different SSIDs, PWs, locations, etc.
// You can have multiple "Personal-info.h" files for them.
#include "Personal-info.h"
//#include "John.h"


#define VERBOSE_CONSOLE // Print more to the serial console (increase String fragmentation?)

// (Frogymandias version) Do we have a touch screen?  (Undefined if no touch screen.)
// If TOUCH is defined then GOTDHT and BUTTON_SWITCHES should be undefined!
// CAROUSEL probably should be defined if TOUCH is defined.
//#define TOUCH

// (Frogymandias) If we are using pullup type switches (instead of the touch screen)
// to switch screens
// Also works with the NodeMCU flash button (and no touch screen)
// Probably best to not define BUTTON_SWITCHES if you are using the touch screen!
#define BUTTON_SWITCHES
#ifdef BUTTON_SWITCHES
#define BUTTON_1 D4 // Left
#define BUTTON_2 D3 // Right (Also is flash button on NodeMCU)
#define BUTTON_DEBOUNCE 100  // in milliseconds
#define BUTTON_LONG_DELAY 600     // Time we keep delaying when detecting long presses
                            // Tradeoff between sluggishness and false long press detection
#define VERY_LONG_TIME 5    // Number of seconds to turn a Long Press into a Very Long Press                            

// These aren't user defined--don't change them. (They are the single bits only, 0001, 0010, 0100, 1000, etc.)
#define BUTTON_1_SHORT  1   // Short press
#define BUTTON_2_SHORT  2
#define BUTTON_1_LONG  4    // Long press
#define BUTTON_2_LONG  8
#define BUTTON_1_VERY_LONG  16    // Very long press
#define BUTTON_2_VERY_LONG  32
#endif  // #ifdef BUTTON_SWITCHES

// (Frogymandias mod) Use the carousel to display advance weather forecasts?
// CAROUSEL should be undefined if GOTDHT is defined
// (The DHT indoor temp/humdity is displayed where the carousel goes.)
//#define CAROUSEL

// (Frogymandias) No carousel.  Going to display temp and humidity where the carousel 
// used to be.  And we will also display temp and humidity from a DHT22
#define GOTDHT
#ifdef GOTDHT
// ESP8266 pin connected to DH22 data line
#define DHT_DATA_PIN D6 // About the only pin left if we are using button switches, above.

// Uncomment whichever type you're using!
//#define DHTTYPE DHT11   // DHT 11
#define DHTTYPE DHT22   // DHT 22  (AM2302), AM2321
//#define DHTTYPE DHT21   // DHT 21 (AM2301)
#endif  // #ifdef GOTDHT

// Display astronomy on screen 0
// (Frogymandias) Currently there is always room for SHOWMOON so only undefine it if
// you have something else to put at the bottom of the screen
#define SHOWMOON

const int UPDATE_INTERVAL_SECS = 10 * 60; // Update every 10 minutes
//const int UPDATE_INTERVAL_SECS = 1 * 60; // Update every 1 minute (Only for testing!)

//const int SLEEP_INTERVAL_SECS = 99.5 * 60;         // Maybe use non-defeatable sleep so the screen won't wear out being on 24/7
                                                  // See Sleep_Interval and TOGGLE_SLEEP, below (if you want to be able to disable sleep.)
//const int SLEEP_INTERVAL_SECS = 9.5 * 60;        // Going to sleep after idle times, set 0 for insomnia
//const int SLEEP_INTERVAL_SECS = 2 * 60;        // Going to sleep after idle times, set 0 for insomnia
//const int SLEEP_INTERVAL_SECS = 1 * 30;       // Mainly for testing.
const int SLEEP_INTERVAL_SECS = 0;        // Going to sleep after idle times, set 0 for insomnia

bool Sleep_Interval = false;               // (Frogymandias) To toggle sleeping on/off with the touch screen or button switches
                                          // We can toggle sleep on/off OR we can toggle the 12/24 hour mode)
                                          // See TOGGLE_12HR, below.
// (Frogymandias) Are we allowed to toggle sleep mode?
// And only if const int SLEEP_INTERVAL_SECS > 0;
// If TOGGLE_SLEEP = false then Sleep_Interval = true is needed if SLEEP_INTERVAL_SECS > 0
// (Otherwise sleep will never happen.)
// How we set Sleep_Interval in settings.h is how sleep mode wakes up.  Toggle...
const bool TOGGLE_SLEEP = false;                                          
                                          
const boolean HARD_SLEEP = false;         // true go into deepSleep false = turn Back light off
/*
  HARD_SLEEP        true  -> deep sleep requiring interrupt or reset to wake
                    false -> soft sleep turning off backlight wake with screen press
                             (Soft sleep reduces power usage about 12%.  The ESP8266 is still cranking.)
 */

/*
Arabic -> ar, Bulgarian -> bg, Catalan -> ca, Czech -> cz, German -> de, Greek -> el,
English -> en, Persian (Farsi) -> fa, Finnish -> fi, French -> fr, Galician -> gl,
Croatian -> hr, Hungarian -> hu, Italian -> it, Japanese -> ja, Korean -> kr,
Latvian -> la, Lithuanian -> lt, Macedonian -> mk, Dutch -> nl, Polish -> pl,
Portuguese -> pt, Romanian -> ro, Russian -> ru, Swedish -> se, Slovak -> sk,
Slovenian -> sl, Spanish -> es, Turkish -> tr, Ukrainian -> ua, Vietnamese -> vi,
Chinese Simplified -> zh_cn, Chinese Traditional -> zh_tw.
*/
const String OPEN_WEATHER_MAP_LANGUAGE = "en";

// Adjust according to your language
const String WDAY_NAMES[] = {"SUN", "MON", "TUE", "WED", "THU", "FRI", "SAT"};
const String MONTH_NAMES[] = {"JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC"};
const String SUN_MOON_TEXT[] = {"Sun", "Rise", "Set", "Moon", "Age", "Illum"};
const String MOON_PHASES[] = {"New Moon", "Waxing Crescent", "First Quarter", "Waxing Gibbous",
                              "Full Moon", "Waning Gibbous", "Third quarter", "Waning Crescent"};

// pick one from TZinfo.h
// (Frogymandias mod) All the time zones are now in x-TZinfo-full.h  Go through x-TZinfo-full.h until you find
// your time zone.  Copy that single line into TZinfo.h
// The entire contents of TZinfo.h is loaded into memory.  We don't need all the time zones in the
// world to be loaded into memory.  Hence, putting all of them into x-TZinfo-full.h, which the program
// never looks at.  This saves about 7K of memory.
String TIMEZONE = getTzInfo("America/New_York");

// values in metric or imperial system?
bool IS_METRIC = false;
//bool IS_METRIC = true;

// Can we toggle IS_METRIC from buttons?
// Use sparingly!  (Invokes a call to OpenWeather)
#define TOGGLE_METRIC_1   // Left
#define TOGGLE_METRIC_2 // Right (and built-in flash button)

// Change for 12 Hour/ 24 hour style clock
bool IS_STYLE_12HR = true;

// (Frogymandias) Are we allowed to toggle 12/24 mode?
// And only if TOGGLE_SLEEP = false (above)
const bool TOGGLE_12HR = false;

// Change for HH:MM/ HH:MM:SS format clock
bool IS_STYLE_HHMM = false; // true => HH:MM

// change for different NTP (time servers)
//#define NTP_SERVERS "pool.ntp.org"
#define NTP_SERVERS "us.pool.ntp.org", "time.nist.gov", "pool.ntp.org"

// Locations on the northern hemisphere (latitude > 0) and those on the southern hemisphere need 
// an inverted set of moon phase icons/characters.
// fully illuminated -> full moon -> char 48
// zero illumination -> new moon -> char 64
const char MOON_ICONS_NORTH_WANING[] = {64, 77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 48};
const char MOON_ICONS_NORTH_WAXING[] = {64, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 48};
const char MOON_ICONS_SOUTH_WANING[] = {64, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 48};
const char MOON_ICONS_SOUTH_WAXING[] = {64, 77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 48};

// August 1st, 2018
#define NTP_MIN_VALID_EPOCH 1533081600

// Pins for the ILI9341 (wemos and NodeMCU)
#define TFT_DC D2   // Red
#define TFT_CS D1   // Grn
#define TFT_LED D8  // Blk

// (Frogymandias mod)
#ifdef TOUCH
  #define HAVE_TOUCHPAD
  #define TOUCH_CS D3
  #define TOUCH_IRQ D4
#endif

/***************************
 * End Settings
 **************************/
#endif  // #ifndef SETTINGS_H
